@@ -8,7 +8,7 @@ pub fn init(font_dirs: &[String], font_family: &str) -> Option<(fontdb::Database
 
     let mut families = font_family
         .split(',')
-        .map(|name| name.trim())
+        .map(str::trim)
         .filter_map(|name| find_font_family(&font_db, name))
         .collect::<Vec<_>>();
 
@@ -17,7 +17,9 @@ pub fn init(font_dirs: &[String], font_family: &str) -> Option<(fontdb::Database
     } else {
         for name in ["DejaVu Sans", "Noto Emoji"] {
             if let Some(name) = find_font_family(&font_db, name) {
-                families.push(name);
+                if !families.contains(&name) {
+                    families.push(name);
+                }
             }
         }
 
@@ -35,7 +37,8 @@ fn find_font_family(font_db: &fontdb::Database, name: &str) -> Option<String> {
         style: fontdb::Style::Normal,
     };
 
-    font_db
-        .query(&query)
-        .map(|face_id| font_db.face(face_id).unwrap().family.clone())
+    font_db.query(&query).and_then(|face_id| {
+        let face_info = font_db.face(face_id).unwrap();
+        face_info.families.first().map(|(family, _)| family.clone())
+    })
 }
