@@ -1,9 +1,3 @@
-use anyhow::{anyhow, Result};
-use clap::ArgEnum;
-use log::info;
-use std::fmt::{Debug, Display};
-use std::io::{BufRead, Write};
-use std::{iter, thread, time::Instant};
 mod asciicast;
 mod events;
 mod fonts;
@@ -11,6 +5,16 @@ mod renderer;
 mod theme;
 mod vt;
 
+use std::fmt::{Debug, Display};
+use std::io::{BufRead, Write};
+use std::{iter, thread, time::Instant};
+
+use anyhow::{anyhow, Result};
+use clap::ArgEnum;
+use log::info;
+
+use crate::asciicast::Asciicast;
+
 pub const DEFAULT_FONT_FAMILY: &str =
     "JetBrains Mono,Fira Code,SF Mono,Menlo,Consolas,DejaVu Sans Mono,Liberation Mono";
 pub const DEFAULT_FONT_SIZE: usize = 14;
@@ -77,6 +81,7 @@ pub enum Theme {
     Nord,
     SolarizedDark,
     SolarizedLight,
+    GruvboxDark,
 
     #[clap(skip)]
     Custom(String),
@@ -99,6 +104,7 @@ impl TryFrom<Theme> for theme::Theme {
             Nord => "2e3440,eceff4,3b4252,bf616a,a3be8c,ebcb8b,81a1c1,b48ead,88c0d0,eceff4,3b4252,bf616a,a3be8c,ebcb8b,81a1c1,b48ead,88c0d0,eceff4".parse(),
             SolarizedDark => "002b36,839496,073642,dc322f,859900,b58900,268bd2,d33682,2aa198,eee8d5,002b36,cb4b16,586e75,657b83,839496,6c71c4,93a1a1,fdf6e3".parse(),
             SolarizedLight => "fdf6e3,657b83,073642,dc322f,859900,b58900,268bd2,d33682,2aa198,eee8d5,002b36,cb4b16,586e75,657c83,839496,6c71c4,93a1a1,fdf6e3".parse(),
+            GruvboxDark => "fbf1c7,282828,282828,cc241d,98971a,d79921,458588,b16286,689d6a,a89984,7c6f64,fb4934,b8bb26,fabd2f,83a598,d3869b,8ec07c,fbf1c7".parse(),
             Custom(t) => t.parse(),
             Embedded(t) => Ok(t),
         }
@@ -118,11 +124,11 @@ impl Display for Theme {
 }
 
 pub fn run<I: BufRead, O: Write + Send>(input: I, output: O, config: Config) -> Result<()> {
-    let (header, events) = asciicast::open(input)?;
+    let Asciicast { header, events, .. } = asciicast::open(input)?;
 
     let terminal_size = (
-        config.cols.unwrap_or(header.terminal_size.0),
-        config.rows.unwrap_or(header.terminal_size.1),
+        config.cols.unwrap_or(header.term_cols as usize),
+        config.rows.unwrap_or(header.term_rows as usize),
     );
 
     let itl = config
@@ -130,8 +136,7 @@ pub fn run<I: BufRead, O: Write + Send>(input: I, output: O, config: Config) ->
         .or(header.idle_time_limit)
         .unwrap_or(DEFAULT_IDLE_TIME_LIMIT);
 
-    let events = asciicast::output(events);
-    let events = iter::once((0.0, "".to_owned())).chain(events);
+    let events = iter::once(Ok((0.0, "".to_owned()))).chain(events);
     let events = events::limit_idle_time(events, itl);
     let events = events::accelerate(events, config.speed);
     let events = events::batch(events, config.fps_cap);
@@ -148,7 +153,7 @@ pub fn run<I: BufRead, O: Write + Send>(input: I, output: O, config: Config) ->
 
     let theme_opt = config
         .theme
-        .or_else(|| header.theme.map(Theme::Embedded))
+        .or_else(|| header.term_theme.map(Theme::Embedded))
         .unwrap_or(Theme::Dracula);
 
     info!("selected theme: {}", theme_opt);
@@ -202,7 +207,8 @@ pub fn run<I: BufRead, O: Write + Send>(input: I, output: O, config: Config) ->
             }
         });
 
-        for (i, (time, lines, cursor)) in frames.enumerate() {
+        for (i, frame) in frames.enumerate() {
+            let (time, lines, cursor) = frame?;
             let image = renderer.render(lines, cursor);
             let time = if i == 0 { 0.0 } else { time };
             collector.add_frame_rgba(i, image, time + config.last_frame_duration)?;
